@@ -3,7 +3,7 @@ package Shipwright::Backend::SVK;
 use warnings;
 use strict;
 use Carp;
-use File::Spec;
+use File::Spec::Functions qw/catfile catdir/;
 use Shipwright::Util;
 use File::Temp qw/tempdir/;
 use File::Copy qw/copy/;
@@ -86,9 +86,9 @@ sub _cmd {
         }
         elsif ( $args{_extra_tests} ) {
             $cmd = [
-                'svk', 'import',
+                'svk',         'import',
                 $args{source}, $self->repository . '/t/extra',
-                '-m', q{'} . $args{comment} . q{'},
+                '-m',          q{'} . $args{comment} . q{'},
             ];
         }
         else {
@@ -114,7 +114,8 @@ sub _cmd {
     }
     elsif ( $type eq 'delete' ) {
         $cmd = [
-            'svk', 'delete', '-m', q{'} . 'delete repository' . q{'},
+            'svk', 'delete', '-m',
+            q{'} . 'delete repository' . q{'},
             $self->repository . $args{path},
         ];
     }
@@ -151,8 +152,8 @@ sub _yml {
     my ($f) = $path =~ m{.*/(.*)$};
 
     if ($yml) {
-        my $dir = tempdir( CLEANUP => 1 );
-        my $file = File::Spec->catfile( $dir, $f );
+        my $dir = tempdir( 'shipwright_XXXXXX', CLEANUP => 1, TMPDIR => 1 );
+        my $file = catfile( $dir, $f );
 
         $self->checkout( path => $path, target => $file );
 
@@ -225,8 +226,8 @@ sub _update_file {
     my $path   = shift;
     my $latest = shift;
 
-    my $dir = tempdir( CLEANUP => 1 );
-    my $file = File::Spec->catfile( $dir, $path );
+    my $dir = tempdir( 'shipwright_XXXXXX', CLEANUP => 1, TMPDIR => 1 );
+    my $file = catfile( $dir, $path );
 
     $self->checkout(
         path   => $path,
