@@ -43,22 +43,18 @@ sub new {
 
     unless ( $self->install_base ) {
 
-        my $dir =
-          tempdir( 'vessel_' . $self->name . '-XXXXXX', TMPDIR => 1 );
+        my $dir = tempdir( 'vessel_' . $self->name . '-XXXXXX', TMPDIR => 1 );
         $self->install_base( catfile( $dir, $self->name ) );
     }
 
     no warnings 'uninitialized';
 
     $ENV{DYLD_LIBRARY_PATH} =
-      catfile( $self->install_base, 'lib' ) . ':'
-      . $ENV{DYLD_LIBRARY_PATH};
+      catfile( $self->install_base, 'lib' ) . ':' . $ENV{DYLD_LIBRARY_PATH};
     $ENV{LD_LIBRARY_PATH} =
-      catfile( $self->install_base, 'lib' ) . ':'
-      . $ENV{LD_LIBRARY_PATH};
+      catfile( $self->install_base, 'lib' ) . ':' . $ENV{LD_LIBRARY_PATH};
     $ENV{PERL5LIB} =
-        catfile( $self->install_base, 'lib', 'perl5', 'site_perl' )
-      . ':'
+        catfile( $self->install_base, 'lib', 'perl5', 'site_perl' ) . ':'
       . catfile( $self->install_base, 'lib', 'perl5' ) . ':'
       . $ENV{PERL5LIB};
     $ENV{PATH} =
@@ -66,10 +62,13 @@ sub new {
       . catfile( $self->install_base, 'sbin' ) . ':'
       . $ENV{PATH};
     $ENV{PERL_MM_USE_DEFAULT} = 1;
+    $ENV{LDFLAGS} .= ' -L' . catfile( $self->install_base, 'lib' );
+    $ENV{CFLAGS}  .= ' -I' . catfile( $self->install_base, 'include' );
 
     require CPAN;
     require Module::Info;
     if ( Module::Info->new_from_module('CPAN::Config') ) {
+
         # keep original CPAN::Config info
         require CPAN::Config;
     }
@@ -108,8 +107,7 @@ sub run {
         dircopy( 'etc', catfile( $self->install_base, 'etc' ) );
 
         my $installed_hash = {};
-        $installed_file =
-          catfile( $self->install_base, 'installed.yml' );
+        $installed_file = catfile( $self->install_base, 'installed.yml' );
         if ( -e $installed_file ) {
             $installed = Shipwright::Util::LoadFile($installed_file);
             $installed_hash = { map { $_ => 1 } @$installed };
@@ -125,7 +123,8 @@ sub run {
         my ( $flags, $ktf );
         if ( -e catfile( 'shipwright', 'flags.yml' ) ) {
 
-            $flags = Shipwright::Util::LoadFile(
+            $flags =
+              Shipwright::Util::LoadFile(
                 catfile( 'shipwright', 'flags.yml' ) );
 
             # fill not specified but mandatory flags
@@ -143,7 +142,8 @@ sub run {
 
         if ( -e catfile( 'shipwright', 'known_test_failures.yml' ) ) {
 
-            $ktf = Shipwright::Util::LoadFile(
+            $ktf =
+              Shipwright::Util::LoadFile(
                 catfile( 'shipwright', 'known_test_failures.yml' ) );
         }
         else {
@@ -170,8 +170,7 @@ sub run {
         @$order = grep { !$installed_hash->{$_} } @$order;
 
         unless ( $self->perl && -e $self->perl ) {
-            my $perl =
-              catfile( $self->install_base, 'bin', 'perl' );
+            my $perl = catfile( $self->install_base, 'bin', 'perl' );
 
             # -e $perl makes sense when we install on to another vessel
             if ( ( grep { /^perl/ } @{$order} ) || -e $perl ) {
@@ -223,8 +222,7 @@ sub _install {
     }
     else {
 
-        my @cmds = read_file(
-            catfile( '..', '..', 'scripts', $dir, 'build' ) );
+        my @cmds = read_file( catfile( '..', '..', 'scripts', $dir, 'build' ) );
         chomp @cmds;
         @cmds = map { $self->_substitute($_) } @cmds;
 
@@ -241,7 +239,6 @@ sub _install {
                 $cmd  = $_;
             }
 
-            next if $type eq 'clean';        # don't need to clean when install
             if ( $self->skip_test && $type eq 'test' ) {
                 $self->log->info("skip build $type part in $dir");
                 next;
@@ -256,17 +253,20 @@ sub _install {
                         $self->log->error(
 "although tests failed, will install anyway since we have force arg\n"
                         );
-                        next;
                     }
                     ## no critic
                     elsif ( eval "$ktf->{$dir}" ) {
                         $self->log->error(
 "although tests failed, will install anyway since it's a known failure\n"
                         );
-                        next;
                     }
+                    next;
+                }
+                elsif ( $type ne 'clean' ) {
+
+                    # clean is trivial, we'll just ignore if 'clean' fails
+                    confess "build $dir $type part with failure.";
                 }
-                die "install failed";
             }
         }
     }
@@ -292,23 +292,17 @@ sub _wrapper {
         mkdir catfile( $self->install_base,       "$dir-wrapped" )
           unless -d catfile( $self->install_base, "$dir-wrapped" );
 
-        if (
-            -e catfile( $self->install_base, "$dir-wrapped", $file )
-          )
-        {
-            $self->log->warn(
-                'found old '
-                  . catfile( $self->install_base, "$dir-wrapped",
-                    $file )
-                  . ', deleting' . "\n"
-            );
-            unlink catfile( $self->install_base, "$dir-wrapped",
-                $file );
+        if ( -e catfile( $self->install_base, "$dir-wrapped", $file ) ) {
+            $self->log->warn( 'found old '
+                  . catfile( $self->install_base, "$dir-wrapped", $file )
+                  . ', deleting'
+                  . "\n" );
+            unlink catfile( $self->install_base, "$dir-wrapped", $file );
         }
 
         my $type;
         if ( -T $file ) {
-            open my $fh, '<', $file or die "can't open $file: $!";
+            open my $fh, '<', $file or confess "can't open $file: $!";
             my $shebang = <$fh>;
             my $base    = quotemeta $self->install_base;
             my $perl    = quotemeta $self->perl;
@@ -326,33 +320,28 @@ sub _wrapper {
             }
         }
 
-        move(
-            $file => catfile( $self->install_base, "$dir-wrapped" )
-        ) or die $!;
+        move( $file => catfile( $self->install_base, "$dir-wrapped" ) )
+          or confess $!;
 
     # if we have this $type(e.g. perl) installed and have that specific wrapper,
     # then link to it, else link to the normal one
         if (   $type
             && -e catfile( '..', 'bin', $type )
-            && -e catfile( '..', 'etc', "shipwright-$type-wrapper" )
-          )
+            && -e catfile( '..', 'etc', "shipwright-$type-wrapper" ) )
         {
-            symlink catfile( '..', 'etc',
-                "shipwright-$type-wrapper" ) => $file
-              or die $!;
+            symlink catfile( '..', 'etc', "shipwright-$type-wrapper" ) => $file
+              or confess $!;
         }
         else {
 
-            symlink catfile( '..', 'etc',
-                'shipwright-script-wrapper' ) => $file
-              or die $!;
+            symlink catfile( '..', 'etc', 'shipwright-script-wrapper' ) => $file
+              or confess $!;
         }
     };
 
     my @dirs =
       grep { -d $_ }
-      map { catfile( $self->install_base, $_ ) }
-      qw/bin sbin/;
+      map { catfile( $self->install_base, $_ ) } qw/bin sbin/;
     find( $sub, @dirs ) if @dirs;
 }
 
@@ -402,7 +391,7 @@ sub test {
         $self->log->info("run tests $type:");
         if ( system($cmd) ) {
             $self->log->error("tests failed");
-            die;
+            confess;
         }
     }
 }
