@@ -17,7 +17,7 @@ use File::Copy qw/copy move/;
 use File::Temp qw/tempdir/;
 use Config;
 use Hash::Merge;
-use List::MoreUtils qw/uniq firstidx/;
+use List::MoreUtils qw/firstidx/;
 
 Hash::Merge::set_behavior('RIGHT_PRECEDENT');
 
@@ -61,7 +61,7 @@ sub run {
 
     }
 
-    die "we need source arg\n" unless $source;
+    confess "we need source arg\n" unless $source;
 
     if ( $self->extra_tests ) {
         $shipwright->backend->import(
@@ -85,7 +85,7 @@ sub run {
                 $self->name($name);
             }
             if ( $self->name !~ /^[-.\w]+$/ ) {
-                die
+                confess
                   qq{name can only have alphanumeric characters, "." and "-"\n};
             }
         }
@@ -136,12 +136,12 @@ sub run {
             $script_dir = catdir( $base, '__scripts', $name );
         }
         else {
+
      # Source part doesn't have script stuff, so we need to create by ourselves.
             $script_dir = tempdir( CLEANUP => 1 );
 
             if ( my $script = $self->build_script ) {
-                copy( $self->build_script,
-                    catfile( $script_dir, 'build' ) );
+                copy( $self->build_script, catfile( $script_dir, 'build' ) );
             }
             else {
                 $self->_generate_build( $source, $script_dir, $shipwright );
@@ -156,7 +156,7 @@ sub run {
                 move(
                     catfile( $source,     '__require.yml' ),
                     catfile( $script_dir, 'require.yml' )
-                ) or die "move __require.yml failed: $!\n";
+                ) or confess "move __require.yml failed: $!\n";
             }
         }
 
@@ -187,7 +187,8 @@ sub run {
             Hash::Merge::merge( $shipwright->backend->source || {}, $new_url )
         );
 
-        $self->_reorder($shipwright);
+        my $new_order = $shipwright->backend->fiddle_order;
+        $shipwright->backend->order( $new_order );
     }
 
     print "imported with success\n";
@@ -197,10 +198,10 @@ sub run {
 # _import_req: import required dists for a dist
 
 sub _import_req {
-    my $self         = shift;
-    my $source       = shift;
-    my $shipwright   = shift;
-    my $script_dir   = shift;
+    my $self       = shift;
+    my $source     = shift;
+    my $shipwright = shift;
+    my $script_dir = shift;
 
     my $require_file = catfile( $source, '__require.yml' );
     $require_file = catfile( $script_dir, 'require.yml' )
@@ -242,18 +243,19 @@ sub _import_req {
 
                     my $script_dir;
                     if ( -e catdir( $dir, '__scripts', $dist ) ) {
-                        $script_dir =
-                          catdir( $dir, '__scripts', $dist );
+                        $script_dir = catdir( $dir, '__scripts', $dist );
                     }
                     else {
-                        $script_dir = tempdir( 'shipwright_XXXXXX',  CLEANUP => 1 , TMPDIR => 1);
+                        $script_dir = tempdir(
+                            'shipwright_XXXXXX',
+                            CLEANUP => 1,
+                            TMPDIR  => 1
+                        );
                         if ( -e catfile( $s, '__require.yml' ) ) {
                             move(
-                                catfile( $s, '__require.yml' ),
-                                catfile(
-                                    $script_dir, 'require.yml'
-                                )
-                            ) or die "move $s/__require.yml failed: $!\n";
+                                catfile( $s,          '__require.yml' ),
+                                catfile( $script_dir, 'require.yml' )
+                            ) or confess "move $s/__require.yml failed: $!\n";
                         }
 
                         $self->_generate_build( $s, $script_dir, $shipwright );
@@ -342,7 +344,7 @@ sub _generate_build {
         push @commands, 'clean: ';
     }
 
-    open my $fh, '>', catfile( $script_dir, 'build' ) or die $@;
+    open my $fh, '>', catfile( $script_dir, 'build' ) or confess $@;
     print $fh $_, "\n" for @commands;
     close $fh;
 }
@@ -357,50 +359,6 @@ sub _parent_dir {
     return catfile(@dirs);
 }
 
-# _reorder:
-# make some hack for order.
-# move ExtUtils::MakeMaker and Module::Build to the head of cpan dists
-
-sub _reorder {
-    my $self       = shift;
-    my $shipwright = shift;
-    my $order      = $shipwright->backend->order;
-
-    my $first_cpan_index = firstidx { /^cpan-/ } @$order;
-
-    unless (
-        (
-            $order->[$first_cpan_index] eq 'cpan-ExtUtils-MakeMaker'
-            && ( ( ( firstidx { $_ eq 'cpan-Module-Build' } @$order ) == -1 )
-                || $order->[ $first_cpan_index + 1 ] eq 'cpan-Module-Build' )
-        )
-        || (
-            $order->[$first_cpan_index] eq 'cpan-Module-Build'
-            && (
-                (
-                    ( firstidx { $_ eq 'cpan-ExtUtils-MakeMaker' } @$order )
-                    == -1
-                )
-                || $order->[ $first_cpan_index + 1 ] eq
-                'cpan-ExtUtils-MakeMaker'
-            )
-        )
-      )
-    {
-        for my $build (qw/cpan-ExtUtils-MakeMaker cpan-Module-Build/) {
-            my $index = firstidx { $build eq $_ } @$order;
-            next if $index == -1;    # $index == -1 if not found
-            if ( $index > $first_cpan_index ) {    # not the 1st cpan dist
-                splice @$order, $first_cpan_index, 0, $build;
-            }
-        }
-    }
-
-    @$order = uniq @$order;
-    $shipwright->backend->order($order);
-
-}
-
 1;
 
 __END__
