@@ -3,7 +3,7 @@ package Shipwright::Source::SVN;
 use warnings;
 use strict;
 use Carp;
-use File::Spec;
+use File::Spec::Functions qw/catfile catdir/;
 
 use base qw/Shipwright::Source::Base/;
 
@@ -49,10 +49,9 @@ sub _run {
     my $self   = shift;
     my $source = $self->source;
 
-
-    my $cmd    = [
+    my $cmd = [
         'svn', 'export', $self->source,
-        File::Spec->catfile( $self->download_directory, $self->name ),
+        catfile( $self->download_directory, $self->name ),
         $self->version ? ( '-r', $self->version ) : (),
     ];
 
@@ -64,8 +63,7 @@ sub _run {
         }
     }
 
-    $self->source(
-        File::Spec->catfile( $self->download_directory, $self->name ) );
+    $self->source( catfile( $self->download_directory, $self->name ) );
     Shipwright::Util->run($cmd);
 }
 
