@@ -3,10 +3,12 @@ package Shipwright::Test;
 use warnings;
 use strict;
 use base qw/Exporter/;
+use Carp;
 
 use File::Temp qw/tempdir/;
 use IPC::Cmd qw/can_run/;
 use File::Spec::Functions qw/catfile catdir/;
+use Shipwright::Util;
 
 our @EXPORT =
   qw/has_svk has_svn create_fs_repo create_svk_repo create_svn_repo devel_cover_enabled test_cmd/;
@@ -21,24 +23,36 @@ Shipwright::Test - useful subs for tests are here
 
 =head2 has_svk
 
-check to see if we have svk or not.
-in fact, it also checks svnadmin since we need that to create repo for svk
+check to see if we have svk or not, also limit the svk version to be 2+.
+in fact, it also checks svnadmin since we need that to create repo for svk.
 
 =cut
 
 sub has_svk {
-    return can_run('svk') && can_run('svnadmin');
+    if ( can_run('svk') && can_run('svnadmin') ) {
+        my $out = Shipwright::Util->run( [ 'svk', '--version' ], 1 );
+        if ( $out && $out =~ /version v(\d)\./i ) {
+            return 1 if $1 >= 2;
+        }
+    }
+    return;
 }
 
 =head2 has_svn
 
-check to see if we have svn or not.
-in fact, it also checks svnadmin since we need that to create repo
+check to see if we have svn or not, also limit the svn version to be 1.4+.
+in fact, it also checks svnadmin since we need that to create repo.
 
 =cut
 
 sub has_svn {
-    return can_run('svn') && can_run('svnadmin');
+    if ( can_run('svn') && can_run('svnadmin') ) {
+        my $out = Shipwright::Util->run( [ 'svn', '--version' ], 1 );
+        if ( $out && $out =~ /version 1\.(\d)/i ) {
+            return 1 if $1 >= 4;
+        }
+    }
+    return;
 }
 
 =head2 create_fs_repo 
@@ -48,7 +62,7 @@ create a repo for fs
 =cut
 
 sub create_fs_repo {
-    return tempdir( 'shipwright_XXXXXX',  CLEANUP => 1 , TMPDIR => 1);
+    return tempdir( 'shipwright_XXXXXX', CLEANUP => 1, TMPDIR => 1 );
 }
 
 =head2 create_svk_repo 
@@ -59,7 +73,7 @@ return $ENV{SVKROOT}
 =cut
 
 sub create_svk_repo {
-    $ENV{SVKROOT} = tempdir( 'shipwright_XXXXXX',  CLEANUP => 1 , TMPDIR => 1);
+    $ENV{SVKROOT} = tempdir( 'shipwright_XXXXXX', CLEANUP => 1, TMPDIR => 1 );
     my $svk_root_local = catfile( $ENV{SVKROOT}, 'local' );
     system("svnadmin create $svk_root_local");
     system("svk depotmap -i");
@@ -74,8 +88,8 @@ return the repo's uri, like file:///tmp/foo
 =cut
 
 sub create_svn_repo {
-    my $repo = tempdir( 'shipwright_XXXXXX',  CLEANUP => 1 , TMPDIR => 1);
-    system("svnadmin create $repo") && die "create repo failed: $!";
+    my $repo = tempdir( 'shipwright_XXXXXX', CLEANUP => 1, TMPDIR => 1 );
+    system("svnadmin create $repo") && confess "create repo failed: $!";
     return "file://$repo";
 }
 
@@ -136,7 +150,7 @@ sub test_cmd {
     require Test::More;
     my ( $out, $err ) = Shipwright::Util->run( $cmd, 1 );    # ingnore failure
 
-    _test_cmd( $out, $exp, $msg ) if defined $exp;
+    _test_cmd( $out, $exp,     $msg )     if defined $exp;
     _test_cmd( $err, $exp_err, $msg_err ) if defined $exp_err;
 }
 
