@@ -4,7 +4,10 @@ use warnings;
 use strict;
 use Carp;
 use IPC::Run3;
-use File::Spec;
+use File::Spec::Functions qw/catfile catdir splitpath splitdir/;
+use File::Temp qw/tempdir/;
+use Cwd qw/abs_path/;
+
 use Shipwright;    # we need this to find where Shipwright.pm lives
 
 our ( $SHIPWRIGHT_ROOT, $SHARE_ROOT );
@@ -67,7 +70,7 @@ sub run {
         $log->error(
             'failed to run ' . join( ' ', @$cmd ) . " with exit number $?" );
 
-        die "something wrong when execute @$cmd: $?" unless $ignore_failure;
+        confess "something wrong when execute @$cmd: $?" unless $ignore_failure;
     }
 
     return wantarray ? ( $out, $err ) : $out;
@@ -85,8 +88,8 @@ sub shipwright_root {
     my $self = shift;
 
     unless ($SHIPWRIGHT_ROOT) {
-        my $dir = ( File::Spec->splitpath( $INC{"Shipwright.pm"} ) )[1];
-        $SHIPWRIGHT_ROOT = File::Spec->rel2abs($dir);
+        my $dir = ( splitpath( $INC{"Shipwright.pm"} ) )[1];
+        $SHIPWRIGHT_ROOT = abs_path($dir);
     }
 
     return ($SHIPWRIGHT_ROOT);
@@ -102,24 +105,19 @@ currently only used to store the initial files in project.
 sub share_root {
     my $self = shift;
 
-    require File::ShareDir;
-    $SHARE_ROOT ||=
-      eval { File::Spec->rel2abs( File::ShareDir::module_dir('Shipwright') ) };
+    unless ($SHARE_ROOT) {
+        my @root = splitdir( $self->shipwright_root );
 
-    unless ( $SHARE_ROOT ) {
+        if ( $root[-2] ne 'blib' && $root[-1] eq 'lib' ) {
 
-        # XXX TODO: This is a bloody hack
-        # Module::Install::Share and File::ShareDir don't play nicely
-        # together
-        my @root = File::Spec->splitdir( $self->shipwright_root );
-        $root[-1] = 'share';                       # replace 'lib' to 'share'
-        $SHARE_ROOT = File::Spec->catdir(@root);
-    }
+            # so it's -Ilib in the Shipwright's source dir
+            $root[-1] = 'share';
+        }
+        else {
+            push @root, qw/auto share dist Shipwright/;
+        }
 
-    if ( $SHARE_ROOT !~ m{([/\\])auto\1share\1}
-            && $SHARE_ROOT =~ m{([/\\])blib\1lib\1} ) {
-        my $sep = $1;
-        $SHARE_ROOT =~ s!${sep}auto$sep!${sep}auto${sep}share${sep}dist${sep}!;
+        $SHARE_ROOT = catdir(@root);
     }
 
     return ($SHARE_ROOT);
@@ -140,7 +138,8 @@ my ( $null_fh, $stdout_fh, $cpan_fh, $cpan_log_path, $cpan_fh_flag );
 open $null_fh, '>', '/dev/null';
 
 $cpan_log_path =
-  File::Spec->catfile( File::Spec->tmpdir, 'shipwright_cpan.log' );
+  catfile( tempdir( 'shipwright_XXXXXX', CLEANUP => 1, TMPDIR => 1 ),
+    'shipwright_cpan.log' );
 open $cpan_fh, '>>', $cpan_log_path;
 $stdout_fh = select;
 
@@ -161,7 +160,7 @@ sub select {
         select $cpan_fh;
     }
     else {
-        die "unknown type: $type";
+        confess "unknown type: $type";
     }
 }
 
